@@ -79,16 +79,6 @@ class ExecutionTime(object):
         print("%s: %s" % (self.info, time.time() - self.now))
 
 
-class SoftwarePropertiesPage():
-    ubuntu_software = 0
-    other_software = 1
-    updates = 2
-    authentication = 3
-    additional_drivers = 4
-    developer_options = 5
-    ubuntu_pro = 6
-
-
 def get_string_with_no_auth_from_source_entry(entry):
     tmp = copy(entry)
     url_parts = urlsplit(tmp.uri)
@@ -99,15 +89,6 @@ def get_string_with_no_auth_from_source_entry(entry):
     return str(tmp)
 
 
-def estimate_kernel_size_in_boot():
-    """ estimate the amount of space that the current kernel takes in /boot """
-    size = 0
-    kver = os.uname()[2]
-    for f in glob.glob("/boot/*%s*" % kver):
-        size += os.path.getsize(f)
-    return size
-
-
 def is_unity_running():
     """ return True if Unity is currently running """
     unity_running = False
@@ -115,7 +96,7 @@ def is_unity_running():
         import dbus
         bus = dbus.SessionBus()
         unity_running = bus.name_has_owner("com.canonical.Unity")
-    except Exception as e:
+    except:
         logging.exception("could not check for Unity dbus service")
     return unity_running
 
@@ -316,10 +297,10 @@ def init_proxy(gsettings=None):
     * then into gconf  (if gconfclient was supplied)
     """
     SYNAPTIC_CONF_FILE = "/root/.synaptic/synaptic.conf"
-    proxies = {}
+    proxy = None
     # generic apt config wins
     if apt_pkg.config.find("Acquire::http::Proxy") != '':
-        proxies["http"] = apt_pkg.config.find("Acquire::http::Proxy")
+        proxy = apt_pkg.config.find("Acquire::http::Proxy")
     # then synaptic
     elif os.path.exists(SYNAPTIC_CONF_FILE):
         cnf = apt_pkg.Configuration()
@@ -329,26 +310,18 @@ def init_proxy(gsettings=None):
             proxy_host = cnf.find("Synaptic::httpProxy")
             proxy_port = str(cnf.find_i("Synaptic::httpProxyPort"))
             if proxy_host and proxy_port:
-                proxies["http"] = "http://%s:%s/" % (proxy_host, proxy_port)
-    if apt_pkg.config.find("Acquire::https::Proxy") != '':
-        proxies["https"] = apt_pkg.config.find("Acquire::https::Proxy")
-    elif "http" in proxies:
-        proxies["https"] = proxies["http"]
+                proxy = "http://%s:%s/" % (proxy_host, proxy_port)
     # if we have a proxy, set it
-    if proxies:
+    if proxy:
         # basic verification
-        for proxy in proxies.values():
-            if not re.match("https?://\w+", proxy):
-                print("proxy '%s' looks invalid" % proxy, file=sys.stderr)
-                return
-        proxy_support = ProxyHandler(proxies)
+        if not re.match("http://\w+", proxy):
+            print("proxy '%s' looks invalid" % proxy, file=sys.stderr)
+            return
+        proxy_support = ProxyHandler({"http": proxy})
         opener = build_opener(proxy_support)
         install_opener(opener)
-        if "http" in proxies:
-            os.putenv("http_proxy", proxies["http"])
-        if "https" in proxies:
-            os.putenv("https_proxy", proxies["https"])
-    return proxies
+        os.putenv("http_proxy", proxy)
+    return proxy
 
 
 def on_battery():
@@ -388,14 +361,16 @@ def inhibit_sleep():
         from gi.repository import Gio, GLib
         connection = Gio.bus_get_sync(Gio.BusType.SYSTEM)
 
-        var, fdlist = connection.call_with_unix_fd_list_sync(
-            'org.freedesktop.login1', '/org/freedesktop/login1',
-            'org.freedesktop.login1.Manager', 'Inhibit',
-            GLib.Variant('(ssss)',
-                         ('shutdown:sleep',
-                          'UpdateManager', 'Updating System',
-                          'block')),
-            None, 0, -1, None, None)
+        var, fdlist = connection.call_with_unix_fd_list_sync('org.freedesktop.login1',
+                                                       '/org/freedesktop/login1',
+                                                       'org.freedesktop.login1.Manager',
+                                                       'Inhibit',
+                                                        GLib.Variant('(ssss)',
+                                                                    ('shutdown:sleep',
+                                                                     'UpdateManager',
+                                                                     'Updating System',
+                                                                     'block')),
+                                                        None, 0, -1, None, None)
         inhibitor = Gio.UnixInputStream(fd=fdlist.steal_fds()[var[0]])
 
         return inhibitor
@@ -403,7 +378,6 @@ def inhibit_sleep():
         #print("could not send the dbus Inhibit signal: %s" % e)
         return False
 
-
 def str_to_bool(str):
     if str == "0" or str.upper() == "FALSE":
         return False
@@ -474,6 +448,8 @@ def get_ubuntu_flavor_name(cache=None):
 
 # Unused by update-manager, but still used by ubuntu-release-upgrader
 def error(parent, summary, message):
+    import gi
+    gi.require_version("Gtk", "3.0")
     from gi.repository import Gtk, Gdk
     d = Gtk.MessageDialog(parent=parent,
                           flags=Gtk.DialogFlags.MODAL,
@@ -519,7 +495,7 @@ def is_port_already_listening(port):
     STATE_LISTENING = '0A'
     # read the data
     with open("/proc/net/tcp") as net_tcp:
-        for line in net_tcp.readlines():
+        for line in net_tcp:
             line = line.strip()
             if not line:
                 continue
