@@ -302,7 +302,7 @@ class NeedRestartDialog(InternalDialog):
         self.add_settings_button()
         self.focus_button = self.add_button(_("Restart _Later"),
                                             self.window_main.close)
-        self.add_button(_("_Restart Now…"), self.restart)
+        self.add_button(_("_Restart Now"), self.restart)
 
     def start(self):
         Dialog.start(self)
