@@ -26,7 +26,6 @@ from gi.repository import Gtk
 from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
-import uaclient.api.u.pro.packages.updates.v1 as ua
 
 GdkX11  # pyflakes
 
@@ -40,7 +39,6 @@ import os
 import subprocess
 import sys
 import time
-import threading
 from gettext import gettext as _
 
 import dbus
@@ -51,10 +49,11 @@ DBusGMainLoop(set_as_default=True)
 from .UnitySupport import UnitySupport
 from .Dialogs import (DistUpgradeDialog,
                       ErrorDialog,
+                      HWEUpgradeDialog,
                       NeedRestartDialog,
                       NoUpdatesDialog,
-                      StoppedUpdatesDialog,
                       PartialUpgradeDialog,
+                      StoppedUpdatesDialog,
                       UnsupportedDialog,
                       UpdateErrorDialog)
 from .MetaReleaseGObject import MetaRelease
@@ -63,7 +62,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import SoftwarePropertiesPage
+from .Core.utils import get_dist
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -84,9 +83,9 @@ class UpdateManager(Gtk.Window):
         self.unity = UnitySupport()
         self.controller = None
         self.cache = None
-        self.ua_security_packages = []
         self.update_list = None
         self.meta_release = None
+        self.hwe_replacement_packages = None
 
         # Basic GTK+ parameters
         self.set_title(_("Software Updater"))
@@ -187,14 +186,15 @@ class UpdateManager(Gtk.Window):
         self._start_pane(None)
         sys.exit(0)
 
-    def show_settings(self, page_number=SoftwarePropertiesPage.updates):
+    def show_settings(self):
         try:
             apt_pkg.pkgsystem_unlock()
         except SystemError:
             pass
         cmd = ["/usr/bin/software-properties-gtk",
-               "--toplevel", "%s" % self.get_window().get_xid(),
-               "--open-tab", str(page_number)]
+               "--open-tab", "2",
+               "--toplevel", "%s" % self.get_window().get_xid()
+               ]
         self._look_busy()
         try:
             p = subprocess.Popen(cmd)
@@ -216,8 +216,14 @@ class UpdateManager(Gtk.Window):
         update_backend = get_backend(self, InstallBackend.ACTION_UPDATE)
         self._start_pane(update_backend)
 
-    def start_install(self):
+    def start_install(self, hwe_upgrade=False):
         install_backend = get_backend(self, InstallBackend.ACTION_INSTALL)
+        if hwe_upgrade:
+            for pkgname in self.hwe_replacement_packages:
+                try:
+                    self.cache[pkgname].mark_install()
+                except SystemError:
+                    pass
         self._start_pane(install_backend)
 
     def start_available(self, cancelled_update=False, error_occurred=False):
@@ -229,56 +235,10 @@ class UpdateManager(Gtk.Window):
                                          cancelled_update, error_occurred)
         self._start_pane(pane)
 
-    def _fetch_ua_updates(self):
-        try:
-            self.ua_updates = ua.updates().updates
-        except Exception as e:
-            print("Error running updates end-point: ", e)
-            self.ua_updates = []
-
-    def _get_ua_security_status(self):
-        self.ua_security_packages = []
-        self.ua_updates = []
-        t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
-        t.start()
-        while t.is_alive():
-            while Gtk.events_pending():
-                Gtk.main_iteration()
-            time.sleep(0.05)
-        for package in self.ua_updates:
-            if (
-                package.provided_by == 'standard-security'
-                or package.provided_by == 'standard-updates'
-            ):
-                continue
-            status = package.status
-            if (
-                status == 'pending_attach'
-                or status == 'pending_enable'
-                or status == 'upgrade_available'
-            ):
-                name = package.package
-                version = package.version
-                size = package.download_size
-                downloadable = status == 'upgrade_available'
-                self.ua_security_packages.append(
-                    (name, version, size, downloadable)
-                )
-        self.cache.create_pro_cache(self.ua_security_packages)
-
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
-        if install_count != 0:
-            header = None
-            desc = None
-            if error_occurred:
-                desc = _("Some software couldn’t be checked for updates.")
-            elif cancelled_update:
-                header = _("You stopped the check for updates.")
-                desc = _("Updated software is available from "
-                         "a previous check.")
-            return UpdatesAvailable(self, header, desc, need_reboot)
-        else:
+        self._check_hwe_support_status()
+        if install_count == 0:
             # Need Restart > New Release > No Updates
             if need_reboot:
                 return NeedRestartDialog(self)
@@ -287,11 +247,26 @@ class UpdateManager(Gtk.Window):
                 return dist_upgrade
             elif cancelled_update:
                 return StoppedUpdatesDialog(self)
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
             else:
                 return NoUpdatesDialog(self, error_occurred=error_occurred)
+        else:
+            header = None
+            desc = None
+            if error_occurred:
+                desc = _("Some software couldn’t be checked for updates.")
+            elif cancelled_update:
+                header = _("You stopped the check for updates.")
+                desc = _("Updated software is available from "
+                         "a previous check.")
+            # Display HWE updates first as an old HWE stack is vulnerable
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
+            return UpdatesAvailable(self, header, desc, need_reboot)
 
-    def start_error(self, update_and_retry, header, desc):
-        if update_and_retry:
+    def start_error(self, is_update_error, header, desc):
+        if is_update_error:
             self._start_pane(UpdateErrorDialog(self, header, desc))
         else:
             self._start_pane(ErrorDialog(self, header, desc))
@@ -344,6 +319,34 @@ class UpdateManager(Gtk.Window):
             self.meta_release.connect("done_downloading", Gtk.main_quit)
         return False
 
+    def _check_hwe_support_status(self):
+        di = distro_info.UbuntuDistroInfo()
+        codename = get_dist()
+        lts = di.is_lts(codename)
+        if not lts:
+            return None
+        HWE = "/usr/bin/hwe-support-status"
+        if not os.path.exists(HWE):
+            return None
+        cmd = [HWE, "--show-replacements"]
+        self._parse_hwe_support_status(cmd)
+
+    def _parse_hwe_support_status(self, cmd):
+        try:
+            subprocess.check_output(cmd)
+            # for debugging
+            # print("nothing unsupported running")
+        except subprocess.CalledProcessError as e:
+            if e.returncode == 10:
+                packages = e.output.strip().split()
+                self.hwe_replacement_packages = []
+                for pkgname in packages:
+                    pkgname = pkgname.decode('utf-8')
+                    if pkgname in self.cache and not self.cache[pkgname].is_installed:
+                        self.hwe_replacement_packages.append(pkgname)
+                # for debugging
+                # print(self.hwe_replacement_packages)
+
     # fixme: we should probably abstract away all the stuff from libapt
     def refresh_cache(self):
         # get the lock
@@ -385,13 +388,9 @@ class UpdateManager(Gtk.Window):
                 Gtk.main_iteration()
         iterate()
 
-        self._get_ua_security_status()
-
         self.update_list = UpdateList(self)
         try:
-            self.update_list.update(self.cache, eventloop_callback=iterate,
-                                    ua_security_packages=self.
-                                    ua_security_packages)
+            self.update_list.update(self.cache, eventloop_callback=iterate)
         except SystemError as e:
             header = _("Could not calculate the upgrade")
             desc = _("An unresolvable problem occurred while "
@@ -405,12 +404,12 @@ class UpdateManager(Gtk.Window):
             self._start_pane(PartialUpgradeDialog(self))
 
     def _setup_dbus(self):
-        """ this sets up a dbus listener if none is installed alread """
+        """ this sets up a dbus listener if none is installed already """
         # check if there is another g-a-i already and if not setup one
         # listening on dbus
         try:
             bus = dbus.SessionBus()
-        except Exception as e:
+        except:
             print("warning: could not initiate dbus")
             return
         try:
@@ -448,7 +447,7 @@ class UpdateManagerDbusController(dbus.service.Object):
         try:
             self.parent.start_install()
             return True
-        except Exception as e:
+        except:
             return False
 
     def _on_network_alert(self, watcher, state):
